==> dl.php?src=linea21_1_6.zip: linea21/dashboard/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage dashboard
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list&amp;scale_id=";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";
$rub_link_rap=$rub_link."&amp;todo=rap&amp;scale_id=";
$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('dashboard','add');
if($todo=='list') $title=_t('dashboard','list');
if($todo=='mod') $title=_t('dashboard','mod');
if($todo=='sup') $title=_t('dashboard','sup');
if($todo=='det') $title=_t('dashboard','det');
if($todo=='rap') $title=_t('dashboard','rap');
?>
<div id="itemenu">
<h1><?php echo $title; ?></h1>
<div class="contentlink">
<a	href="<?php echo $rub_link_rap.$scale_id; ?>" id="content_link_report" title="<?php echo _t('dashboard','rap');?>"><?php echo _t('dashboard','rap');?></a>
| <a href="<?php echo $rub_link_list.$scale_id; ?>" id="content_link_list" title="<?php echo _t('dashboard','list');?>"><?php echo _t('dashboard','list');?></a>
| <a href="<?php echo $search; ?>" id="content_link_search" title="<?php echo _t('menu','search');?>"><?php echo _t('menu','search');?></a>
</div>
</div>

==> dl.php?src=linea21_1_7.zip: linea21/dashboard/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage dashboard
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list&amp;scale_id=";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_sup=$rub_link."&amp;todo=sup";
$rub_link_rap=$rub_link."&amp;todo=rap&amp;scale_id=";
$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('dashboard','add');
if($todo=='list') $title=_t('dashboard','list');
if($todo=='mod') $title=_t('dashboard','mod');
if($todo=='sup') $title=_t('dashboard','sup');
if($todo=='det') $title=_t('dashboard','det');
if($todo=='rap') $title=_t('dashboard','rap');
?>
<div id="itemenu">
<h1><?php echo $title; ?></h1>
<div class="contentlink">
<a	href="<?php echo $rub_link_rap.$scale_id; ?>" title="<?php echo _t('dashboard','rap');?>"><i class="icon-export"></i><?php echo _t('dashboard','rap');?></a>
| <a href="<?php echo $rub_link_list.$scale_id; ?>" title="<?php echo _t('dashboard','list');?>"><i class="icon-list"></i><?php echo _t('dashboard','list');?></a>
| <a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
</div>
</div>
